export P=qwt
export V=6.1.3
export B=5
export MAINTAINER=JuergenFischer

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

[ -f qwt-$V.tar.bz2 ] || wget https://sourceforge.net/projects/qwt/files/qwt/$V/qwt-$V.tar.bz2
if ! [ -f ../qwtbuild.pri ]; then
	tar -C .. -xjf qwt-$V.tar.bz2 --xform s,qwt-$V,.,
	patch -d .. <diff
fi

if ! [ -d "$OSGEO4W_REP" ]; then
        echo no repository
        exit 1
fi

fetchenv() {
        local IFS
        IFS=
        batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        /usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        /usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in x86 x86_64; do
	export ARCH

	(
		case "$ARCH" in
		x86)
        		export O4W_ROOT=/c/OSGeo4W
        		export VCARCH=x86
			;;

		x86_64)
			export O4W_ROOT=/c/OSGeo4W64
	        	export VCARCH=amd64
			;;

		*)
        		echo invalid arch
        		exit 1
			;;

		esac

		export R=$OSGEO4W_REP/$ARCH/release/qt5/$P

		for i in doc libs devel; do
			mkdir -p $R/$P-$i-qt5
			cp ../COPYING $R/$P-$i-qt5/$P-$i-qt5-$V-$B.txt
		done

		cat <<EOF >$R/$P-doc-qt5/setup.hint
sdesc: "Qt5 widgets library for technical applications (Documentation)"
ldesc: "Qt5 widgets library for technical applications (Documentation)"
maintainer: $MAINTAINER
category: Libs
requires: shell 
external-source: qwt-libs-qt5
EOF

		cat <<EOF >$R/$P-libs-qt5/setup.hint
sdesc: "Qt5 widgets library for technical applications (runtime)"
ldesc: "Qt5 widgets library for technical applications (runtime)"
maintainer: $MAINTAINER
category: Libs
requires: shell qt5-libs
EOF

		cat <<EOF >$R/$P-devel-qt5/setup.hint
sdesc: "Qt5 widgets library for technical applications (Development)"
ldesc: "Qt5 widgets library for technical applications (Development)"
maintainer: $MAINTAINER
category: Libs
requires: shell qwt-libs-qt5
external-source: qwt-libs-qt5
EOF

		fetchenv $O4W_ROOT/bin/o4w_env.bat
		fetchenv $O4W_ROOT/bin/qt5_env.bat
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH
		export PATH="$PATH:/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/Common7/IDE:/bin"

		rm -rf install
		mkdir -p install

		cd ..

		[ -f Makefile ] && nmake distclean
		qmake qwt.pro
		nmake clean
		nmake
		nmake install

		cd osgeo4w

		/usr/bin/tar -C install -cjvf $R/$P-doc-qt5/$P-doc-qt5-$V-$B.tar.bz2 \
			apps/qwt6/doc

		/usr/bin/tar -C install -cjvf $R/$P-libs-qt5/$P-libs-qt5-$V-$B.tar.bz2 \
			--xform s,apps/Qt5/lib/qwt6.dll,apps/Qt5/bin/qwt6.dll, \
			apps/Qt5/lib/qwt6.dll

		/usr/bin/tar -C install -cjvf $R/$P-devel-qt5/$P-devel-qt5-$V-$B.tar.bz2 \
			--absolute-names \
			--xform s,../../lib/qwt6.lib,apps/Qt5/lib/qwt.lib, \
			--xform s,../.././lib/qwt6.lib,apps/Qt5/lib/qwt6.lib, \
			apps/Qt5/features \
			apps/Qt5/include/qwt6 \
			../../lib/qwt6.lib \
			../.././lib/qwt6.lib \
			apps/Qt5/plugins/designer/qwt_designer_plugin6.dll

		/usr/bin/tar -C .. -cjvf $R/$P-libs-qt5/$P-libs-qt5-$V-$B-src.tar.bz2 \
			osgeo4w/package.sh osgeo4w/diff
	)
done

date

